==> seedsui-react-3.0.2.tgz: package/es/IndexBar/IndexBar.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp2;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import Instance from './instance.js';

var IndexBar = (_temp2 = _class = function (_Component) {
  _inherits(IndexBar, _Component);

  function IndexBar() {
    var _temp, _this, _ret;

    _classCallCheck(this, IndexBar);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = _possibleConstructorReturn(this, _Component.call.apply(_Component, [this].concat(args))), _this), _this.componentDidUpdate = function () {
      var _this$props = _this.props,
          overflowContainer = _this$props.overflowContainer,
          parent = _this$props.parent,
          indexs = _this$props.indexs;

      var $overflowContainer = overflowContainer || _this.$el.parentNode;
      _this.instance.updateParams({
        overflowContainer: $overflowContainer,
        parent: parent || document.body,
        indexs: indexs
      });
    }, _temp), _possibleConstructorReturn(_this, _ret);
  }

  IndexBar.prototype.componentDidMount = function componentDidMount() {
    var _props = this.props,
        overflowContainer = _props.overflowContainer,
        parent = _props.parent,
        indexs = _props.indexs;

    var $overflowContainer = overflowContainer || this.$el.parentNode;
    var instance = new Instance({
      overflowContainer: $overflowContainer,
      parent: parent || document.body,
      indexs: indexs
    });
    this.instance = instance;
  };

  IndexBar.prototype.render = function render() {
    var _this2 = this;

    var _props2 = this.props,
        overflowContainer = _props2.overflowContainer,
        parent = _props2.parent,
        indexs = _props2.indexs,
        others = _objectWithoutProperties(_props2, ['overflowContainer', 'parent', 'indexs']);

    return React.createElement(
      'div',
      _extends({ ref: function ref(el) {
          _this2.$el = el;
        } }, others, { className: 'indexbar' + (others.className ? ' ' + others.className : '') }),
      indexs.map(function (index, i) {
        return React.createElement(
          'a',
          { href: ';', key: 'btn' + i },
          index
        );
      })
    );
  };

  return IndexBar;
}(Component), _class.defaultProps = {
  indexs: ['A', 'B', 'C', 'D', 'E', 'F', 'G', 'H', 'I', 'G', 'K', 'L', 'M', 'N', 'O', 'P', 'Q', 'R', 'S', 'T', 'U', 'V', 'W', 'X', 'Y', 'Z']
}, _temp2);
export { IndexBar as default };
IndexBar.propTypes = process.env.NODE_ENV !== "production" ? {
  overflowContainer: PropTypes.any, // 滚动区域
  parent: PropTypes.any, // DOM注入容器
  indexs: PropTypes.array
} : {};

==> seedsui-react-3.0.4.tgz: package/es/IndexBar/IndexBar.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp2;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import Instance from './instance.js';
import { createPortal } from 'react-dom';

var IndexBar = (_temp2 = _class = function (_Component) {
  _inherits(IndexBar, _Component);

  function IndexBar() {
    var _temp, _this, _ret;

    _classCallCheck(this, IndexBar);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = _possibleConstructorReturn(this, _Component.call.apply(_Component, [this].concat(args))), _this), _this.componentDidUpdate = function () {
      var _this$props = _this.props,
          portal = _this$props.portal,
          overflowContainer = _this$props.overflowContainer,
          indexs = _this$props.indexs;

      var parent = portal || _this.$el.parentNode;
      _this.instance.updateParams({
        overflowContainer: overflowContainer,
        parent: parent,
        indexs: indexs
      });
    }, _temp), _possibleConstructorReturn(_this, _ret);
  }

  IndexBar.prototype.componentDidMount = function componentDidMount() {
    var _props = this.props,
        portal = _props.portal,
        overflowContainer = _props.overflowContainer,
        indexs = _props.indexs;

    var parent = portal || this.$el.parentNode;
    var instance = new Instance({
      overflowContainer: overflowContainer,
      parent: parent,
      indexs: indexs
    });
    this.instance = instance;
  };

  IndexBar.prototype.render = function render() {
    var _this2 = this;

    var _props2 = this.props,
        portal = _props2.portal,
        overflowContainer = _props2.overflowContainer,
        indexs = _props2.indexs,
        others = _objectWithoutProperties(_props2, ['portal', 'overflowContainer', 'indexs']);

    if (portal) {
      return createPortal(React.createElement(
        'div',
        _extends({ ref: function ref(el) {
            _this2.$el = el;
          } }, others, { className: 'indexbar' + (others.className ? ' ' + others.className : '') }),
        indexs.map(function (index, i) {
          return React.createElement(
            'a',
            { href: ';', key: 'btn' + i },
            index
          );
        })
      ), portal);
    }
    return React.createElement(
      'div',
      _extends({ ref: function ref(el) {
          _this2.$el = el;
        } }, others, { className: 'indexbar' + (others.className ? ' ' + others.className : '') }),
      indexs.map(function (index, i) {
        return React.createElement(
          'a',
          { href: ';', key: 'btn' + i },
          index
        );
      })
    );
  };

  return IndexBar;
}(Component), _class.defaultProps = {
  indexs: ['A', 'B', 'C', 'D', 'E', 'F', 'G', 'H', 'I', 'G', 'K', 'L', 'M', 'N', 'O', 'P', 'Q', 'R', 'S', 'T', 'U', 'V', 'W', 'X', 'Y', 'Z']
}, _temp2);
export { IndexBar as default };
IndexBar.propTypes = process.env.NODE_ENV !== "production" ? {
  portal: PropTypes.object,
  overflowContainer: PropTypes.any, // 滚动区域
  indexs: PropTypes.array
} : {};
